@@ -96,8 +96,8 @@ class MathBinary(JavaTransformer, HasOutputCol, JavaMLReadable, JavaMLWritable):
 
             scalaMathBinaryModel = _jvm().ml.combust.mleap.core.feature.MathBinaryModel(
                 scalaBinaryOperation,
-                Some(defaultA) if defaultA else ScalaNone(),
-                Some(defaultB) if defaultB else ScalaNone(),
+                Some(defaultA) if defaultA is not None else ScalaNone(),
+                Some(defaultB) if defaultB is not None else ScalaNone(),
             )
             self._java_obj = self._new_java_obj(
                 "org.apache.spark.ml.mleap.feature.MathBinary",
