@@ -1,4 +1,3 @@
-
 #
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
@@ -16,21 +15,18 @@
 # limitations under the License.
 #
 
-import unittest
-import pandas as pd
-import numpy as np
-import os
-import shutil
 import json
-import uuid
+import shutil
 import tempfile
+import unittest
 
+import numpy as np
+import pandas as pd
 from mleap.sklearn.preprocessing.data import FeatureExtractor, MathUnary, MathBinary, StringMap
-from mleap.sklearn.preprocessing.data import StandardScaler, MinMaxScaler, LabelEncoder, Imputer, Binarizer, PolynomialFeatures
-from mleap.sklearn.preprocessing.data import OneHotEncoder
-
+from mleap.sklearn.preprocessing.data import StandardScaler, MinMaxScaler, LabelEncoder, Binarizer, PolynomialFeatures
 from pandas.util.testing import assert_frame_equal
 
+
 class TransformerTests(unittest.TestCase):
     def setUp(self):
         self.df = pd.DataFrame(np.random.randn(10, 5), columns=['a', 'b', 'c', 'd', 'e'])
@@ -369,68 +365,6 @@ class TransformerTests(unittest.TestCase):
         self.assertEqual(le.input_features, label_encoder_tf.input_features)
         self.assertEqual(le.output_features, label_encoder_tf.output_features[0])
 
-    def one_hot_encoder_serializer_test(self):
-
-        labels = ['a', 'b', 'c']
-
-        le = LabelEncoder(input_features=['label_feature'],
-                          output_features='label_feature_le_encoded')
-
-        oh_data = le.fit_transform(labels).reshape(3, 1)
-
-        one_hot_encoder_tf = OneHotEncoder(sparse=False)
-        one_hot_encoder_tf.mlinit(prior_tf=le,
-                                  output_features='{}_one_hot_encoded'.format(le.output_features))
-        one_hot_encoder_tf.fit(oh_data)
-
-        one_hot_encoder_tf.serialize_to_bundle(self.tmp_dir, one_hot_encoder_tf.name)
-
-        # Test model.json
-        with open("{}/{}.node/model.json".format(self.tmp_dir, one_hot_encoder_tf.name)) as json_data:
-            model = json.load(json_data)
-
-        self.assertEqual(one_hot_encoder_tf.op, model['op'])
-        self.assertEqual(3, model['attributes']['size']['long'])
-        self.assertEqual(True, model['attributes']['drop_last']['boolean'])
-        self.assertEqual('error', model['attributes']['handle_invalid']['string'])
-
-    def one_hot_encoder_deserializer_test(self):
-
-        labels = ['a', 'b', 'c']
-
-        le = LabelEncoder(input_features=['label_feature'],
-                          output_features='label_feature_le_encoded')
-
-        oh_data = le.fit_transform(labels).reshape(3, 1)
-
-        one_hot_encoder_tf = OneHotEncoder(sparse=False)
-        one_hot_encoder_tf.mlinit(prior_tf = le,
-                                  output_features='{}_one_hot_encoded'.format(le.output_features))
-        one_hot_encoder_tf.fit(oh_data)
-
-        one_hot_encoder_tf.serialize_to_bundle(self.tmp_dir, one_hot_encoder_tf.name)
-
-        # Deserialize the OneHotEncoder
-        node_name = "{}.node".format(one_hot_encoder_tf.name)
-        one_hot_encoder_tf_ds = OneHotEncoder()
-        one_hot_encoder_tf_ds.deserialize_from_bundle(self.tmp_dir, node_name)
-
-        # Transform some sample data
-        res_a = one_hot_encoder_tf.transform(oh_data)
-        res_b = one_hot_encoder_tf_ds.transform(oh_data)
-
-        self.assertEqual(res_a[0][0], res_b[0][0])
-        self.assertEqual(res_a[1][0], res_b[1][0])
-        self.assertEqual(res_a[2][0], res_b[2][0])
-
-        # Test node.json
-        with open("{}/{}.node/node.json".format(self.tmp_dir, one_hot_encoder_tf.name)) as json_data:
-            node = json.load(json_data)
-
-        self.assertEqual(one_hot_encoder_tf_ds.name, node['name'])
-        self.assertEqual(one_hot_encoder_tf_ds.input_features[0], node['shape']['inputs'][0]['name'])
-        self.assertEqual(one_hot_encoder_tf_ds.output_features[0], node['shape']['outputs'][0]['name'])
-
     def feature_extractor_test(self):
 
         extract_features = ['a', 'd']
@@ -486,60 +420,6 @@ class TransformerTests(unittest.TestCase):
         self.assertEqual(expected_model['attributes']['input_shapes']['data_shape'][1]['isNullable'],
                      model['attributes']['input_shapes']['data_shape'][1]['isNullable'])
 
-    def imputer_test(self):
-
-        def _set_nulls(df):
-            row = df['index']
-            if row in [2,5]:
-                return np.NaN
-            return df.a
-
-        extract_features = ['a']
-        feature_extractor = FeatureExtractor(input_scalars=['a'],
-                                         output_vector='extracted_a_output',
-                                         output_vector_items=["{}_out".format(x) for x in extract_features])
-
-        imputer = Imputer(strategy='mean')
-        imputer.mlinit(prior_tf=feature_extractor,
-                       output_features='a_imputed')
-
-        df2 = self.df
-        df2.reset_index(inplace=True)
-        df2['a'] = df2.apply(_set_nulls, axis=1)
-
-        imputer.fit(df2[['a']])
-
-        self.assertAlmostEqual(imputer.statistics_[0], df2.a.mean(), places = 7)
-
-        imputer.serialize_to_bundle(self.tmp_dir, imputer.name)
-
-        expected_model = {
-          "op": "imputer",
-          "attributes": {
-            "surrogate_value": {
-              "double": df2.a.mean()
-            },
-            "strategy": {
-              "string": "mean"
-            }
-          }
-        }
-
-        # Test model.json
-        with open("{}/{}.node/model.json".format(self.tmp_dir, imputer.name)) as json_data:
-            model = json.load(json_data)
-
-        self.assertEqual(expected_model['attributes']['strategy']['string'], model['attributes']['strategy']['string'])
-        self.assertAlmostEqual(expected_model['attributes']['surrogate_value']['double'], model['attributes']['surrogate_value']['double'], places = 7)
-
-        # Test node.json
-        with open("{}/{}.node/node.json".format(self.tmp_dir, imputer.name)) as json_data:
-            node = json.load(json_data)
-
-        self.assertEqual(imputer.name, node['name'])
-        self.assertEqual(imputer.input_features, node['shape']['inputs'][0]['name'])
-        self.assertEqual(imputer.output_features, node['shape']['outputs'][0]['name'])
-
     def binarizer_test(self):
 
         extract_features = ['a']
